==> visitor_analytics-8.x-1.1.tar.gz: visitor_analytics/src/Form/RegisterForm.php <==
<?php

namespace Drupal\visitor_analytics\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\visitor_analytics\VisitorAnalyticsExistingUserException;
use Drupal\visitor_analytics\VisitorAnalyticsRequest;

/**
 * Class RegisterForm.
 */
class RegisterForm extends FormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'register_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#images'] = drupal_get_path('module', 'visitor_analytics');
    $form['#attached']['library'][] = 'visitor_analytics/visa-styles';

    $form['firstName'] = [
      '#type' => 'textfield',
      '#title' => $this->t('First Name'),
      '#maxlength' => 256,
      '#size' => 64,
      '#weight' => '0',
      '#required' => TRUE,
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];
    $form['lastName'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Last Name'),
      '#maxlength' => 256,
      '#size' => 64,
      '#weight' => '1',
      '#required' => TRUE,
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];
    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email'),
      '#weight' => '2',
      '#required' => TRUE,
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];
    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
      '#maxlength' => 64,
      '#size' => 64,
      '#weight' => '3',
      '#required' => TRUE,
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];
    $form['companyName'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Company Name'),
      '#maxlength' => 1024,
      '#size' => 64,
      '#weight' => '4',
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];

    $form['terms'] = [
      '#type' => 'checkbox',
      '#title' => $this->makeTermsOfUseText(),
      '#weight' => '5',
      '#required' => TRUE,
    ];

    $form['newsletterSubscribed'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Keep me updated with Visitor Analytics news and offers and tips&tricks about analytics.'),
      '#weight' => '6',
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Create account'),
      '#weight' => 7,
      '#attributes' => [
        'class' => ['button', 'theme-green',],
      ],
    ];

    $form['#theme'] = 'visitor_analytics_register_form';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $data = [
      'email' => $form_state->getValue('email'),
      'password' => $form_state->getValue('password'),
      'firstName' => $form_state->getValue('firstName'),
      'lastName' => $form_state->getValue('lastName'),
      'companyName' => $form_state->getValue('companyName'),
      'privacyTermsAccepted' => $form_state->getValue('terms'),
      'dpaAccepted' => $form_state->getValue('terms'),
      'businessConditionAccepted' => $form_state->getValue('terms'),
      'newsletterSubscribed' => $form_state->getValue('newsletterSubscribed'),
      'source' => 'DRUPAL',
    ];

    $request = new VisitorAnalyticsRequest();

    try {
      $request->registerUser($data);
    } catch (VisitorAnalyticsExistingUserException $e) {
      \Drupal::messenger()->addError($this->t($e->getMessage()));
      return $this->redirect('visitor_analytics.login_form');
    } catch (\Exception $e) {
      \Drupal::messenger()->addError($this->t($e->getMessage()));
      \Drupal::logger('visitor_analytics')->error($this->t($e->getMessage()));
    }

    \Drupal::messenger()->addMessage($this->t('You have successfully registered at visitor-analytics.io. Please, check your mailbox for email confirmation letter.'));
    $form_state->setRedirect('visitor_analytics.login_form');
    $data = \Drupal::state()->get('visitor_analytics', []);
    $data['email'] = $form_state->getValue('email');
    \Drupal::state()->set('visitor_analytics', $data);
  }

  /**
   *
   * Creates a text for Terms of Use
   *
   * @return string
   */
  protected function makeTermsOfUseText() {
    $termsUrl = Url::fromUri('https://www.visitor-analytics.io/standard-terms-and-conditions', [
      'absolute' => TRUE,
    ]);
    $dpaUrl = Url::fromUri('https://www.visitor-analytics.io/standard-data-processing-agreement', [
      'absolute' => TRUE,
    ]);

    $terms = Link::fromTextAndUrl($this->t('Terms Of Use'), $termsUrl);
    $dpa = Link::fromTextAndUrl($this->t('Data Processing Agreement'), $dpaUrl);

    return $this->t('I confirm that I have read, consent and agree to Visitor Analytics @terms and @dpa.', [
      '@terms' => $terms->toString(),
      '@dpa' => $dpa->toString(),
    ]);
  }

}

==> visitor_analytics-8.x-1.3.tar.gz: visitor_analytics/src/Form/RegisterForm.php <==
<?php

namespace Drupal\visitor_analytics\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\visitor_analytics\VisitorAnalyticsExistingUserException;
use Drupal\visitor_analytics\VisitorAnalyticsRequest;

/**
 * Class RegisterForm.
 */
class RegisterForm extends FormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'register_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#images'] = drupal_get_path('module', 'visitor_analytics');
    $form['#attached']['library'][] = 'visitor_analytics/visa-styles';

    // check if already has data
    $visitor_analytics_data = \Drupal::state()->get('visitor_analytics', []);
    if (isset($visitor_analytics_data['email'])) {
      \Drupal::messenger()->addWarning(
        t('Please note that you already have an account related to this website. The tracking will be transferred on the new account (without previous data) and it won\'t be performed on the old one any longer.')
      );
    }

    $form['firstName'] = [
      '#type' => 'textfield',
      '#title' => $this->t('First Name'),
      '#maxlength' => 256,
      '#size' => 64,
      '#weight' => '0',
      '#required' => TRUE,
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];
    $form['lastName'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Last Name'),
      '#maxlength' => 256,
      '#size' => 64,
      '#weight' => '1',
      '#required' => TRUE,
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];
    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email'),
      '#weight' => '2',
      '#required' => TRUE,
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];
    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
      '#maxlength' => 64,
      '#size' => 64,
      '#weight' => '3',
      '#required' => TRUE,
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];
    $form['companyName'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Company Name'),
      '#maxlength' => 1024,
      '#size' => 64,
      '#weight' => '4',
      '#title_display' => 'invisible',
      '#theme_wrappers' => [],
      '#attributes' => [
        'class' => ['notification-input'],
      ],
    ];

    $form['terms'] = [
      '#type' => 'checkbox',
      '#title' => $this->makeTermsOfUseText(),
      '#weight' => '5',
      '#required' => TRUE,
    ];

    $form['newsletterSubscribed'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Keep me updated with Visitor Analytics news and offers and tips&tricks about analytics.'),
      '#weight' => '6',
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Create account'),
      '#weight' => 7,
      '#attributes' => [
        'class' => ['button', 'theme-green',],
      ],
    ];

    $form['#theme'] = 'visitor_analytics_register_form';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $data = [
      'email' => $form_state->getValue('email'),
      'password' => $form_state->getValue('password'),
      'firstName' => $form_state->getValue('firstName'),
      'lastName' => $form_state->getValue('lastName'),
      'companyName' => $form_state->getValue('companyName'),
      'privacyTermsAccepted' => $form_state->getValue('terms'),
      'dpaAccepted' => $form_state->getValue('terms'),
      'businessConditionAccepted' => $form_state->getValue('terms'),
      'newsletterSubscribed' => $form_state->getValue('newsletterSubscribed'),
      'source' => 'DRUPAL',
    ];

    $request = new VisitorAnalyticsRequest();

    try {
      $request->registerUser($data);
    } catch (VisitorAnalyticsExistingUserException $e) {
      \Drupal::messenger()->addError($this->t($e->getMessage()));
      return $this->redirect('visitor_analytics.login_form');
    } catch (\Exception $e) {
      \Drupal::messenger()->addError($this->t($e->getMessage()));
      \Drupal::logger('visitor_analytics')->error($this->t($e->getMessage()));
    }

    \Drupal::messenger()->addMessage($this->t('You have successfully registered at visitor-analytics.io. Please, check your mailbox for email confirmation letter.'));
    $form_state->setRedirect('visitor_analytics.login_form');
    // After each new registration all old data must be reset:
    $data = [];
    $data['email'] = $form_state->getValue('email');
    \Drupal::state()->set('visitor_analytics', $data);
  }

  /**
   *
   * Creates a text for Terms of Use
   *
   * @return string
   */
  protected function makeTermsOfUseText() {
    $termsUrl = Url::fromUri('https://www.visitor-analytics.io/standard-terms-and-conditions', [
      'absolute' => TRUE,
    ]);
    $dpaUrl = Url::fromUri('https://www.visitor-analytics.io/standard-data-processing-agreement', [
      'absolute' => TRUE,
    ]);

    $terms = Link::fromTextAndUrl($this->t('Terms Of Use'), $termsUrl);
    $dpa = Link::fromTextAndUrl($this->t('Data Processing Agreement'), $dpaUrl);

    return $this->t('I confirm that I have read, consent and agree to Visitor Analytics @terms and @dpa.', [
      '@terms' => $terms->toString(),
      '@dpa' => $dpa->toString(),
    ]);
  }

}
